@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Main::Constants qw(PE_OK PE_BADCREDENTIALS);
 
 extends qw(Lemonldap::NG::Portal::Auth::_WebForm);
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.9';
 
 # INITIALIZATION
 
@@ -32,7 +32,8 @@ sub init {
 sub authenticate {
     my ( $self, $req ) = @_;
 
-    unless ( $req->{user} eq $req->datas->{password} ) {
+    unless ( $req->{user} eq $req->data->{password} ) {
+        $self->userLogger->warn("Bad password for $req->{user}");
         $self->setSecurity($req);
         return PE_BADCREDENTIALS;
     }
