@@ -7,7 +7,7 @@ use Lemonldap::NG::Common::UserAgent;
 use Lemonldap::NG::Portal::Main::Constants qw(PE_OK PE_ERROR PE_BADCREDENTIALS);
 use Lemonldap::NG::Common::FormEncode;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.11';
 
 has ua => ( is => 'rw' );
 
@@ -17,7 +17,7 @@ sub init {
     my ($self) = @_;
     $self->conf->{remoteCookieName} ||= $self->conf->{cookieName};
     $self->conf->{proxySessionService} ||=
-      $self->conf->{proxyAuthService} . '/mysession';
+      $self->conf->{proxyAuthService} . '/session/my';
     $self->conf->{proxySessionService} =~ s#/*$##;
     $self->ua( Lemonldap::NG::Common::UserAgent->new( $self->conf ) );
     $self->ua->default_header( Accept => 'application/json' );
@@ -34,18 +34,18 @@ no warnings 'once';
 
 sub getUser {
     my ( $self, $req ) = @_;
-    return PE_OK if ( $req->datas->{_proxyQueryDone} );
+    return PE_OK if ( $req->data->{_proxyQueryDone} );
     $self->logger->debug(
         'Proxy push auth to ' . $self->conf->{proxyAuthService} );
     my $resp = $self->ua->post( $self->conf->{proxyAuthService},
-        { user => $req->{user}, password => $req->datas->{password} } );
+        { user => $req->{user}, password => $req->data->{password} } );
     unless ( $resp->is_success ) {
         $self->logger->error(
             'Unable to query authentication service: ' . $resp->status_line );
         return PE_ERROR;
     }
     $self->logger->debug('Proxy gets a response');
-    my $res = eval { JSON::from_json( $resp->content ) };
+    my $res = eval { JSON::from_json( $resp->content, { allow_nonref => 1 } ) };
     if ($@) {
         $self->logger->error("Bad content: $@");
         return PE_ERROR;
@@ -64,9 +64,15 @@ sub getUser {
     PE_OK;
 }
 
+sub findUser {
+
+    # Nothing to do here
+    PE_OK;
+}
+
 sub setSessionInfo {
     my ( $self, $req ) = @_;
-    return PE_OK if ( $req->datas->{_setSessionInfoDone} );
+    return PE_OK if ( $req->data->{_setSessionInfoDone} );
     my $q = HTTP::Request->new(
         GET => $self->conf->{proxySessionService} . '/global',
         [
@@ -81,7 +87,7 @@ sub setSessionInfo {
         return PE_ERROR;
     }
     $self->logger->debug('Proxy gets a response');
-    my $res = eval { JSON::from_json( $resp->content ) };
+    my $res = eval { JSON::from_json( $resp->content, { allow_nonref => 1 } ) };
     if ($@) {
         $self->logger->error("Bad content: $@");
         return PE_ERROR;
@@ -89,7 +95,7 @@ sub setSessionInfo {
     foreach ( keys %$res ) {
         $req->{sessionInfo}->{$_} ||= $res->{$_} unless (/^_/);
     }
-    $req->datas->{_setSessionInfoDone}++;
+    $req->data->{_setSessionInfoDone}++;
     PE_OK;
 }
 
